@@ -737,6 +737,8 @@ class OpenShift:
         specification: Dict[str, Any],
         target: str,
         parameters: Dict[str, Any],
+        *,
+        raw_specification: Optional[Dict[str, Any]] = None,
     ) -> Optional[str]:
         """Schedule an inspection run."""
         if not self.amun_inspection_namespace:
@@ -764,7 +766,12 @@ class OpenShift:
 
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
         workflow_parameters["dockerfile"] = dockerfile
-        workflow_parameters["specification"] = json.dumps(specification)
+        # Propagate raw specification to be placed on Ceph, not to submit escaped specification.
+        workflow_parameters["specification"] = (
+            json.dumps(raw_specification)
+            if raw_specification is not None
+            else json.dumps(specification)
+        )
         workflow_parameters["target"] = target
 
         if "batch_size" in specification:
@@ -1175,11 +1182,9 @@ class OpenShift:
 
         if source_type is not None:
             self._verify_thoth_integration(source_type=source_type)
-            source_type_enum = (
-                getattr(ThothAdviserIntegrationEnum, source_type)
-                if source_type
-                else None
-            )
+        source_type_enum = (
+            getattr(ThothAdviserIntegrationEnum, source_type) if source_type else None
+        )
 
         self.verify_integration_inputs(
             source_type=source_type_enum,
@@ -1327,16 +1332,16 @@ class OpenShift:
             },
         )
 
-    def schedule_srcopsmetrics_workflow(self, repository: str) -> Optional[str]:
-        """Schedule SrcOpsMetrics Workflow.
+    def schedule_mi_workflow(self, repository: str) -> Optional[str]:
+        """Schedule Meta-information Indicators Workflow.
 
         :param repository:str: GitHub repository in full name format: <repo_owner>/<repo_name>
         """
-        workflow_id = self.generate_id("srcopsmetrics")
+        workflow_id = self.generate_id("mi")
         template_parameters = {"WORKFLOW_ID": workflow_id, "REPOSITORY": repository}
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_srcopsmetrics,
+            workflow=self.workflow_manager.submit_mi,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": {},
