@@ -748,12 +748,12 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_srcopsmetrics(
+    def submit_mi(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
     ) -> Optional[str]:
-        """Submit SrcOpsMetrics workflow."""
+        """Submit Meta-information Indicators workflow."""
         if not self.openshift.infra_namespace:
             raise ConfigurationError("Infra namespace was not provided.")
 
@@ -765,7 +765,7 @@ class WorkflowManager:
 
         workflow_id: Optional[str] = self.submit_workflow_from_template(
             self.openshift.infra_namespace,
-            label_selector="template=srcopsmetrics",
+            label_selector="template=mi",
             template_parameters=template_parameters,
             workflow_parameters=workflow_parameters,
             workflow_namespace=self.openshift.middletier_namespace,
